async library

Classes

StreamConsumerWrapper<S>
The StreamConsumer wrapper
StreamUtil
Stream utilities
StreamWrapper<T>
A Stream wrapper

Functions

cancelDeferred(Object key, {String? category}) → bool
Cancels the deferred execution of the given key. Returns true if the task is not yet executed.
clearDefers() → int
Clears all pending deferred tasks queued by defer, dropping them without running — the opposite of flushDefers.
configureDefers({FutureOr executor(Object key, Function task, String? category, {void onActionDone()?, void onError(Object ex, StackTrace st)?})?, Duration? executable(int runningCount)?, Duration? maxBusy}) → void
Configures how to execute a deferred task.
defer<T>(T key, FutureOr task(T key), {Duration min = const Duration(seconds: 1), Duration? max, String? category}) → void
Defers the execution of a task. If the key is the same, the task in the second invocation will override the previous. In other words, the previous task is canceled.
flushDefers({void onActionStart(Object key, String? category)?, void onActionDone(Object key, String? category)?, void onError(Object ex, StackTrace st)?, Duration? repeatLater}) → FutureOr
Force all deferred task (queued by defer) to execute. If the task given in defer returns an instance of Future, this method will wait until it completes.