StreamConsumerWrapper<S> class

The StreamConsumer wrapper

Implemented types
Implementers

Constructors

StreamConsumerWrapper(StreamConsumer<S>? origin)
Constructor.

Properties

hashCode → int
The hash code for this object.
no setterinherited
origin → StreamConsumer<S>
The original stream consumer
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addStream(Stream<S> stream) → Future
Consumes the elements of stream.
override
close() → Future
Tells the consumer that no further streams will be added.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited