Browser class abstract

The browser.

Constructors

Browser()

Properties

android ↔ bool
Whether it is running on Android.
getter/setter pair
androidVersion ↔ double?
The version of Android if it is running on Android, or null if not.
getter/setter pair
chrome ↔ bool
Whether it is Chrome.
getter/setter pair
firefox ↔ bool
Whether it is Firefox.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
ie ↔ bool
Whether it is Internet Explorer.
getter/setter pair
iOS ↔ bool
Whether it is running on iOS.
getter/setter pair
iOSVersion ↔ double?
The version of iOS if it is running on iOS, or null if not.
getter/setter pair
legacyEdge → bool
Whether it is legacy Edge. Note: if it is legacy Edge, we consider it as a variant of Chrome, so chrome is also true but version is not correct.
no setter
linux ↔ bool
Whether it is running on Linux.
getter/setter pair
macOS ↔ bool
Whether it is running on MacOS.
getter/setter pair
mobile ↔ bool
Whether it is running on a mobile device.
getter/setter pair
newEdge → bool
Whether it is new Edge. Note: if it is new Edge, we consider it as a variant of Chrome, so chrome is also true.
no setter
opera ↔ bool
Whether it is Presto-era Opera or Opera Mini. Modern Blink-based Opera (OPR/) is detected as chrome.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
safari ↔ bool
Whether it is Safari.
getter/setter pair
userAgent → String
Returns the user agent.
no setter
version ↔ double
The browser's version.
getter/setter pair
webkit ↔ bool
Whether it is WebKit-based.
getter/setter pair
webkitVersion ↔ double?
The webkit's version if this is a webkit-based browser, or null
getter/setter pair
windows ↔ bool
Whether it is running on Windows.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

parseVersion(String version, {String separator = '.', bool twoDigits = false}) → double
Parses the given version into a double.