convert library

Functions

readAsJson(Stream<List<int>> stream, {Encoding encoding = utf8, int? maxLength}) Future
Reads the entire stream as a JSON string using the given Encoding, and then converts to an object.
readAsString(Stream<List<int>> stream, {Encoding encoding = utf8, int? maxLength}) Future<String>
Reads the entire stream as a string using the given Encoding.

Exceptions / Errors

PayloadException
Exception thrown by readAsString and readAsJson when the input stream exceeds the allowed length.