HttpRequestWrapper class

The HTTP request wrapper.

Implemented types

Constructors

HttpRequestWrapper(HttpRequest? origin)
Constructor.

Properties

certificate → X509Certificate?
The client certificate of the client making the request.
no setteroverride
connectionInfo → HttpConnectionInfo?
Information about the client connection.
no setteroverride
contentLength → int
The content length of the request body.
no setteroverride
cookies → List<Cookie>
The cookies in the request, from the "Cookie" headers.
no setteroverride
first → Future<Uint8List>
The first element of this stream.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
headers → HttpHeaders
The request headers.
no setteroverride
isBroadcast → bool
Whether this stream is a broadcast stream.
no setteroverride
isEmpty → Future<bool>
Whether this stream contains any elements.
no setteroverride
last → Future<Uint8List>
The last element of this stream.
no setteroverride
length → Future<int>
The number of elements in this stream.
no setteroverride
method → String
The method, such as 'GET' or 'POST', for the request.
no setteroverride
origin → HttpRequest
The origin stream
no setter
persistentConnection → bool
The persistent connection state signaled by the client.
no setteroverride
protocolVersion → String
The HTTP protocol version used in the request, either "1.0" or "1.1".
no setteroverride
requestedUri → Uri
The requested URI for the request.
no setteroverride
response → HttpResponse
The HttpResponse object, used for sending back the response to the client.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
session → HttpSession
The session for the given request.
no setteroverride
single → Future<Uint8List>
The single element of this stream.
no setteroverride
uri → Uri
The URI for the request.
no setteroverride

Methods

any(bool test(Uint8List element)) → Future<bool>
Checks whether test accepts any element provided by this stream.
override
asBroadcastStream({void onListen(StreamSubscription<Uint8List> subscription)?, void onCancel(StreamSubscription<Uint8List> subscription)?}) → Stream<Uint8List>
Returns a multi-subscription stream that produces the same events as this.
override
asyncExpand<E>(Stream<E>? convert(Uint8List event)) → Stream<E>
Transforms each element into a sequence of asynchronous events.
override
asyncMap<E>(FutureOr<E> convert(Uint8List event)) → Stream<E>
Creates a new stream with each data event of this stream asynchronously mapped to a new event.
override
cast<R>() → Stream<R>
Adapt this stream to be a Stream<R>.
override
contains(Object? needle) → Future<bool>
Returns whether needle occurs in the elements provided by this stream.
override
distinct([bool equals(Uint8List previous, Uint8List next)?]) → Stream<Uint8List>
Skips data events if they are equal to the previous data event.
override
drain<E>([E? futureValue]) → Future<E>
Discards all data on this stream, but signals when it is done or an error occurred.
override
elementAt(int index) → Future<Uint8List>
Returns the value of the indexth data event of this stream.
override
every(bool test(Uint8List element)) → Future<bool>
Checks whether test accepts all elements provided by this stream.
override
expand<S>(Iterable<S> convert(Uint8List element)) → Stream<S>
Transforms each element of this stream into a sequence of elements.
override
firstWhere(bool test(Uint8List element), {Uint8List orElse()?}) → Future<Uint8List>
Finds the first element of this stream matching test.
override
fold<S>(S initialValue, S combine(S previous, Uint8List element)) → Future<S>
Combines a sequence of values by repeatedly applying combine.
override
forEach(void action(Uint8List element)) → Future
Executes action on each element of this stream.
override
handleError(Function onError, {bool test(dynamic error)?}) → Stream<Uint8List>
Creates a wrapper Stream that intercepts some errors from this stream.
override
join([String separator = '']) → Future<String>
Combines the string representation of elements into a single string.
override
lastWhere(bool test(Uint8List element), {Uint8List orElse()?}) → Future<Uint8List>
Finds the last element in this stream matching test.
override
listen(void onData(Uint8List event)?, {Function? onError, void onDone()?, bool? cancelOnError}) → StreamSubscription<Uint8List>
Adds a subscription to this stream.
override
map<S>(S convert(Uint8List event)) → Stream<S>
Transforms each element of this stream into a new stream event.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pipe(StreamConsumer<Uint8List> streamConsumer) → Future
Pipes the events of this stream into streamConsumer.
override
reduce(Uint8List combine(Uint8List previous, Uint8List element)) → Future<Uint8List>
Combines a sequence of values by repeatedly applying combine.
override
singleWhere(bool test(Uint8List element), {Uint8List orElse()?}) → Future<Uint8List>
Finds the single element in this stream matching test.
override
skip(int count) → Stream<Uint8List>
Skips the first count data events from this stream.
override
skipWhile(bool test(Uint8List element)) → Stream<Uint8List>
Skip data events from this stream while they are matched by test.
override
take(int count) → Stream<Uint8List>
Provides at most the first count data events of this stream.
override
takeWhile(bool test(Uint8List element)) → Stream<Uint8List>
Forwards data events while test is successful.
override
timeout(Duration timeLimit, {void onTimeout(EventSink<Uint8List> sink)?}) → Stream<Uint8List>
Creates a new stream with the same events as this stream.
override
toList() → Future<List<Uint8List>>
Collects all elements of this stream in a List.
override
toSet() → Future<Set<Uint8List>>
Collects the data of this stream in a Set.
override
toString() → String
A string representation of this object.
override
transform<S>(StreamTransformer<Uint8List, S> streamTransformer) → Stream<S>
Applies streamTransformer to this stream.
override
where(bool test(Uint8List element)) → Stream<Uint8List>
Creates a new stream from this stream that discards some elements.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited