NoSuchClassError class

Exception thrown because of non-existing class.

Implemented types
Annotations
  • @Deprecated('rikulo_mirrors uses dart:mirrors and is unsupported on AOT/web. Consider package:reflectable or code generation.')

Constructors

NoSuchClassError([dynamic message])
const

Properties

hashCode int
The hash code for this object.
no setterinherited
message → dynamic
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited