InvokeUtil class

Utilities related to invocations.

Constructors

InvokeUtil()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

invokeSafely<T>(FutureOr<T?> action(), {void onError(dynamic ex)?}) Future<T?>
Invokes action, catching any exception it throws. If onError is given, it is called with the exception; otherwise the exception is silently ignored.
invokeSafelyWith<T, A>(FutureOr<T?> action(A arg), A arg, {void onError(dynamic ex)?}) Future<T?>
Invokes action, catching any exception it throws. If onError is given, it is called with the exception; otherwise the exception is silently ignored.