Trio<F, S, T> class

Represents a tuple of objects. It is useful for implementing a function returning a trio of objects.

Constructors

Trio(F first, S second, T third)
const
Trio.from((F, S, T) value)
Trio.fromJson(List json)

Properties

first → F
final
hashCode → int
The hash code for this object.
no setteroverride
last → T
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
second → S
final
third → T
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → List
toString() → String
A string representation of this object.
override

Operators

operator ==(Object o) → bool
The equality operator.
override