convert library
Functions
-
readAsJson(
Stream< List< stream, {Encoding encoding = utf8, int? maxLength}) → Futureint> > - Reads the entire stream as a JSON string using the given Encoding, and then converts to an object.
-
readAsString(
Stream< List< stream, {Encoding encoding = utf8, int? maxLength}) → Future<int> >String> - Reads the entire stream as a string using the given Encoding.
Exceptions / Errors
- PayloadException
- Exception thrown by readAsString and readAsJson when the input stream exceeds the allowed length.