write method
Converts object to a String by invoking Object.toString and
adds the encoding of the result to the target consumer.
This operation is non-blocking. See flush or done for how to get any errors generated by this call.
Implementation
@override
void write(Object? obj) {
String string = '$obj';
if (string.isEmpty) return;
add(encoding.encode(string));
}